@@ -35,6 +35,16 @@ class CCURE(MSSQL):
         self.cursor.execute(query)
         return list(self.cursor.fetchall())
 
-    def update(self):
+    def update(
+        self,
+        credentials_path="credentials.csv",
+        newpersonnel_path="newpersonnel.csv",
+        personnel_path="personnel.csv",
+    ):
         """Return an Update object for CCURE."""
-        return Update(self)
+        return Update(
+            ccure=self,
+            credentials_path=credentials_path,
+            newpersonnel_path=newpersonnel_path,
+            personnel_path=personnel_path,
+        )
