@@ -100,9 +100,13 @@ class Update:
             output = []
             for key in p:
                 if key in [
-                    "id",
+                    "company",
+                    "disabled",
                     "guid",
+                    "id",
+                    "middle_name",
                     "personnel_type_id",
+                    "personnel_type_name",
                 ]:
                     continue
                 if key not in person:
